@@ -153,9 +153,16 @@ def google_drive(dir='/gdrive'):
     print(f'\nGoogle Drive authentication starts...')
     drive.mount(dir)
 
-def GCSconnect():
-    print('\nGCS authentication starts...')
-    auth.authenticate_user()
+def GCSconnect(save_to_file_path=None):
+    if save_to_file_path:
+        print('Upload your Google Storage API token')
+        files.upload()
+        subprocess.call(f'chmod 600 {save_to_file_path}', shell=True)        
+        os.environ['GOOGLE_APPLICATION_CREDENTIALS'] = f'{save_to_file_path}' 
+        subprocess.call('echo $GOOGLE_APPLICATION_CREDENTIALS', shell=True)
+    else:
+        print('\nGCS authentication starts...')
+        auth.authenticate_user()
 
 def _create_bucket(project, bucket_name):
     storage_client = storage.Client(project=project)
